{% extends "stampo.htm"%}
{% block title %}Error{% endblock %}
{% block content %}
<div class="title">
    <img class="logo" src="https://ryg.s3.fr-par.scw.cloud/logos/blue/logo.svg">
    <div class="logo-text">{{e}}</div>
    <div class="logo-subtitle">{{text}}</div>
</div>
{% endblock %}